@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: config.c,v 1.48 2007/04/01 16:36:21 hany Exp $
+ * $Id: config.c,v 1.50 2007/04/14 17:21:50 hany Exp $
  */
 
 #include <config.h>
@@ -725,11 +725,14 @@ void reinitialize(void) {
     rpm2html_url = NULL;
     rpm2html_ftp = NULL;
     rpm2html_ftpsrc = NULL;
+    if (rpm2html_host != NULL && rpm2html_host != rpm2html_rpm2html_thishost) xmlFree(rpm2html_host);
     rpm2html_host = rpm2html_rpm2html_thishost;
     rpm2html_build_tree = 0;
     rpm2html_dump_rdf = 0;
     rpm2html_dump_rdf_resources = 0;
     rpm2html_dump_html = 1;
+    if (rpm2html_html_template != NULL) xmlFree(rpm2html_html_template);
+    rpm2html_html_template = "rpm2html.tpl";
     if (rpm2html_rdf_dir != NULL) xmlFree(rpm2html_rdf_dir);
     rpm2html_rdf_dir = NULL;
     if (rpm2html_rdf_resources_dir != NULL) xmlFree(rpm2html_rdf_resources_dir);
