@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rdf.c,v 1.47 2000/12/10 17:10:38 veillard Exp $
+ * $Id: rdf.c,v 1.48 2007/04/14 15:45:28 hany Exp $
  */
 
 #include "config.h"
@@ -917,6 +917,9 @@ void dumpAllResRdf(void) {
 
     if (!rpm2html_dump_rdf_resources) return;
 
+    if (rpm2htmlVerbose)
+      printf("Dumping resource RDF\n");
+
     cur = ressList;
 
     while (cur != NULL) {
@@ -949,6 +952,9 @@ void dumpAproposRdf(void) {
     if (rpm2html_rdf_resources_dir != NULL) base = rpm2html_rdf_resources_dir;
     else return;
 
+    if (rpm2htmlVerbose)
+      printf("Dumping apropos RDF\n");
+
     snprintf(file, sizeof(file), "%s/fullIndex.rdf.gz", base);
     if (rpm2htmlVerbose > 1) {
         printf("Dumping %s\n", file);
@@ -1256,6 +1262,9 @@ void dumpDistListRdf(void) {
     if (rpm2html_rdf_resources_dir != NULL) base = rpm2html_rdf_resources_dir;
     else return;
 
+    if (rpm2htmlVerbose)
+      printf("Dumping distribution RDF\n");
+
     dumpMetadataListRdf();
 
     snprintf(file, sizeof(file), "%s/distribs", base);
