@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpm2html.h,v 1.74 2007/04/01 16:36:21 hany Exp $
+ * $Id: rpm2html.h,v 1.75 2007/04/14 17:32:29 hany Exp $
  */
 
 #ifndef __RPM2HTML_H__
@@ -16,10 +16,10 @@
  * General setup default values overriden by config file.
  */
 #define RPM2HTML_NAME	"rpm2html"
-#define RPM2HTML_VER	"1.9.3"
-#define RPM2HTML_URL    "http://rpmfind.net/linux/rpm2html/"
-#define RPM2HTML_MAINT	"Daniel Veillard"
-#define RPM2HTML_MAIL 	"daniel@veillard.com"
+#define RPM2HTML_VER	"1.9.4"
+#define RPM2HTML_URL    "http://www.nongnu.org/rpm2html/"
+#define RPM2HTML_MAINT	"Peter Hanecak"
+#define RPM2HTML_MAIL 	"hany@hany.sk"
 
 /*
  * Constants.
