@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.117 2007/04/01 16:47:40 hany Exp $
+ * $Id: rpmopen.c,v 1.118 2007/04/14 17:21:50 hany Exp $
  */
 
 #include <config.h>
@@ -720,6 +720,7 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
         }
         *res = '\0';
         rpm->extra->changelog = xmlStrdup(protectEmail(buffer));
+        ENTRY_CLEANUP(names);
     }
     ENTRY_CLEANUP(p);
     if (rpm->vendor == NULL) {
@@ -1003,8 +1004,10 @@ rpmAnalyze(char *path, char *nameRpm, const char *sigtarget,
 
     /* dump the HTML related to this package */
     if ((rpm2html_dump_html) && (dir->html))
+        // TODO compare also last-modification-time of package on HTML (if existing) and dump HTML only if package is newer or page does not exists
         dumpRpmHtml(rpm, tree);
     if (rpm2html_dump_rdf)
+        // TODO compare also last-modification-time of package on RDF (if existing) and dump RDF only if package is newer or RDF does not exists
         dumpRpmRdf(rpm, tree);
 
     /* free the extra data */
